@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use XSLoader;
 
-our $VERSION = '0.203000';
+our $VERSION = '0.300000';
 
 eval {
     require HTTP::Headers::Fast;
@@ -13,6 +13,7 @@ eval {
     *HTTP::Headers::Fast::DESTROY                = *HTTP::XSHeaders::DESTROY;
     *HTTP::Headers::Fast::clone                  = *HTTP::XSHeaders::clone;
     *HTTP::Headers::Fast::header                 = *HTTP::XSHeaders::header;
+    *HTTP::Headers::Fast::_header                = *HTTP::XSHeaders::_header;
     *HTTP::Headers::Fast::clear                  = *HTTP::XSHeaders::clear;
     *HTTP::Headers::Fast::push_header            = *HTTP::XSHeaders::push_header;
     *HTTP::Headers::Fast::init_header            = *HTTP::XSHeaders::init_header;
@@ -40,6 +41,7 @@ eval {
     *HTTP::Headers::new                    = *HTTP::XSHeaders::new;
     *HTTP::Headers::clone                  = *HTTP::XSHeaders::clone;
     *HTTP::Headers::header                 = *HTTP::XSHeaders::header;
+    *HTTP::Headers::_header                = *HTTP::XSHeaders::_header;
     *HTTP::Headers::clear                  = *HTTP::XSHeaders::clear;
     *HTTP::Headers::push_header            = *HTTP::XSHeaders::push_header;
     *HTTP::Headers::init_header            = *HTTP::XSHeaders::init_header;
@@ -270,7 +272,7 @@ HTTP::Headers::Fast.
 
 =head1 VERSION
 
-Version 0.203000
+Version 0.300000
 
 =head1 SYNOPSIS
 
